# Copyright 2006, Rick Wilson 

# Permission to use, copy, modify, and distribute this software for 
# any purpose and without fee is hereby granted, provided that the above
# copyright notice appear in all copies.

# THIS SOFTWARE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR
# IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
# WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.

# Name :          groupByLayer.rb 1.0
# Description :   Explodes groups/components, regroups all model entities by layer.
# Author :        Rick Wilson
# Usage :         1. Install into the plugins directory or into the 
#                    Plugins/examples directory and manually load from the ruby console "load 'examples/groupByLayer.rb'" 
#                 2. Run "Group by layer" from the Plugins menu.
# Date :          2006-10-18
# Type :          Tool
# History:        1.0 (2006-10-18) - first version
#
 
require 'sketchup.rb'

def layer_groups
	model=Sketchup.active_model
	defs=model.definitions
	ents=model.active_entities
	sel=model.selection
	comgrp=[]
	layers=model.layers
	layerNames=[]
	layers.each {|l| layerNames<<l.name}

	model.start_operation "Bomb"

	count=0
	defs.each {|d| count+=d.count_instances}
	total=count
	while count > 0
		defs.each do |d|
 			puts "#{defs.count} definitions"
	 		puts "exploding #{d.name}"
			d.instances.each do |e|
				e.explode
			end
		end
		count=0
		defs.each {|d| count+=d.count_instances}
		Sketchup.set_status_text "#{count} of #{total} instances remaining"
	end

	model.commit_operation

#		SORT BY LAYER

	model.start_operation "Group"

	layerNames.each do |m|
		sel.clear
		ents.each do |ee|
			sel.add(ee) if ee.layer.name == m
		end
		ents.add_group(sel)
	end
	sel.clear

	model.commit_operation
end

if( not file_loaded?("groupByLayer.rb") )
    add_separator_to_menu("Plugins")
# BEGIN CHANGES BY organizerEdit.rb
if $submenu!=nil
    $submenu.add_item("Group by layer") { layer_groups }
else
    UI.menu("Plugins").add_item("Group by layer") { layer_groups }
end
# END CHANGES BY organizerEdit.rb
end
#-----------------------------------------------------------------------------
file_loaded("groupByLayer.rb")
